.wp-block-comments-pagination>.wp-block-comments-pagination-next,.wp-block-comments-pagination>.wp-block-comments-pagination-numbers,.wp-block-comments-pagination>.wp-block-comments-pagination-previous{
  font-size:inherit;
  margin-bottom:.5em;
  margin-right:.5em;
}
.wp-block-comments-pagination>.wp-block-comments-pagination-next:last-child,.wp-block-comments-pagination>.wp-block-comments-pagination-numbers:last-child,.wp-block-comments-pagination>.wp-block-comments-pagination-previous:last-child{
  margin-right:0;
}
.wp-block-comments-pagination .wp-block-comments-pagination-previous-arrow{
  display:inline-block;
  margin-right:1ch;
}
.wp-block-comments-pagination .wp-block-comments-pagination-previous-arrow:not(.is-arrow-chevron){
  transform:scaleX(1);
}
.wp-block-comments-pagination .wp-block-comments-pagination-next-arrow{
  display:inline-block;
  margin-left:1ch;
}
.wp-block-comments-pagination .wp-block-comments-pagination-next-arrow:not(.is-arrow-chevron){
  transform:scaleX(1);
}
.wp-block-comments-pagination.aligncenter{
  justify-content:center;
}