ol.wp-block-latest-comments{
  box-sizing:border-box;
  margin-left:0;
}

:where(.wp-block-latest-comments:not([style*=line-height] .wp-block-latest-comments__comment)){
  line-height:1.1;
}

:where(.wp-block-latest-comments:not([style*=line-height] .wp-block-latest-comments__comment-excerpt p)){
  line-height:1.8;
}

.has-dates :where(.wp-block-latest-comments:not([style*=line-height])),.has-excerpts :where(.wp-block-latest-comments:not([style*=line-height])){
  line-height:1.5;
}

.wp-block-latest-comments .wp-block-latest-comments{
  padding-left:0;
}

.wp-block-latest-comments__comment{
  list-style:none;
  margin-bottom:1em;
}
.has-avatars .wp-block-latest-comments__comment{
  list-style:none;
  min-height:2.25em;
}
.has-avatars .wp-block-latest-comments__comment .wp-block-latest-comments__comment-excerpt,.has-avatars .wp-block-latest-comments__comment .wp-block-latest-comments__comment-meta{
  margin-left:3.25em;
}

.wp-block-latest-comments__comment-excerpt p{
  font-size:.875em;
  margin:.36em 0 1.4em;
}

.wp-block-latest-comments__comment-date{
  display:block;
  font-size:.75em;
}

.wp-block-latest-comments .avatar,.wp-block-latest-comments__comment-avatar{
  border-radius:1.5em;
  display:block;
  float:left;
  height:2.5em;
  margin-right:.75em;
  width:2.5em;
}

.wp-block-latest-comments[class*=-font-size] a,.wp-block-latest-comments[style*=font-size] a{
  font-size:inherit;
}