.wp-block-audio{
  margin-left:0;
  margin-right:0;
  position:relative;
}
.wp-block-audio.is-transient audio{
  opacity:.3;
}
.wp-block-audio .components-spinner{
  left:50%;
  margin-left:-9px;
  margin-top:-9px;
  position:absolute;
  top:50%;
}