.wp-block[data-align=center]>.wp-block-table,.wp-block[data-align=left]>.wp-block-table,.wp-block[data-align=right]>.wp-block-table{
  height:auto;
}
.wp-block[data-align=center]>.wp-block-table table,.wp-block[data-align=left]>.wp-block-table table,.wp-block[data-align=right]>.wp-block-table table{
  width:auto;
}
.wp-block[data-align=center]>.wp-block-table td,.wp-block[data-align=center]>.wp-block-table th,.wp-block[data-align=left]>.wp-block-table td,.wp-block[data-align=left]>.wp-block-table th,.wp-block[data-align=right]>.wp-block-table td,.wp-block[data-align=right]>.wp-block-table th{
  word-break:break-word;
}
.wp-block[data-align=center]>.wp-block-table{
  text-align:initial;
}
.wp-block[data-align=center]>.wp-block-table table{
  margin:0 auto;
}
.wp-block-table td,.wp-block-table th{
  border:1px solid;
  padding:.5em;
}
.wp-block-table td.is-selected,.wp-block-table th.is-selected{
  border-color:var(--wp-admin-theme-color);
  border-style:double;
  box-shadow:inset 0 0 0 1px var(--wp-admin-theme-color);
}
.wp-block-table table.has-individual-borders td,.wp-block-table table.has-individual-borders th,.wp-block-table table.has-individual-borders tr,.wp-block-table table.has-individual-borders>*{
  border:1px solid;
}

.blocks-table__placeholder-form.blocks-table__placeholder-form{
  align-items:flex-start;
  display:flex;
  flex-direction:column;
  gap:8px;
}
@media (min-width:782px){
  .blocks-table__placeholder-form.blocks-table__placeholder-form{
    align-items:flex-end;
    flex-direction:row;
  }
}

.blocks-table__placeholder-input{
  width:112px;
}