.wp-block-pullquote{
  box-sizing:border-box;
  margin:0 0 1em;
  overflow-wrap:break-word;
  padding:4em 0;
  text-align:center;
}
.wp-block-pullquote blockquote,.wp-block-pullquote cite,.wp-block-pullquote p{
  color:inherit;
}
.wp-block-pullquote blockquote{
  margin:0;
}
.wp-block-pullquote p{
  margin-top:0;
}
.wp-block-pullquote p:last-child{
  margin-bottom:0;
}
.wp-block-pullquote.alignleft,.wp-block-pullquote.alignright{
  max-width:420px;
}
.wp-block-pullquote cite,.wp-block-pullquote footer{
  position:relative;
}
.wp-block-pullquote .has-text-color a{
  color:inherit;
}

.wp-block-pullquote.has-text-align-left blockquote{
  text-align:left;
}

.wp-block-pullquote.has-text-align-right blockquote{
  text-align:right;
}

.wp-block-pullquote.has-text-align-center blockquote{
  text-align:center;
}

.wp-block-pullquote.is-style-solid-color{
  border:none;
}
.wp-block-pullquote.is-style-solid-color blockquote{
  margin-left:auto;
  margin-right:auto;
  max-width:60%;
}
.wp-block-pullquote.is-style-solid-color blockquote p{
  font-size:2em;
  margin-bottom:0;
  margin-top:0;
}
.wp-block-pullquote.is-style-solid-color blockquote cite{
  font-style:normal;
  text-transform:none;
}

.wp-block-pullquote cite{
  color:inherit;
  display:block;
}