.wp-block-latest-posts{
  box-sizing:border-box;
}
.wp-block-latest-posts.alignleft{
  margin-right:2em;
}
.wp-block-latest-posts.alignright{
  margin-left:2em;
}
.wp-block-latest-posts.wp-block-latest-posts__list{
  list-style:none;
}
.wp-block-latest-posts.wp-block-latest-posts__list li{
  clear:both;
  overflow-wrap:break-word;
}
.wp-block-latest-posts.is-grid{
  display:flex;
  flex-wrap:wrap;
}
.wp-block-latest-posts.is-grid li{
  margin:0 0 1.25em 1.25em;
  width:100%;
}
@media (min-width:600px){
  .wp-block-latest-posts.columns-2 li{
    width:calc(50% - .625em);
  }
  .wp-block-latest-posts.columns-2 li:nth-child(2n){
    margin-left:0;
  }
  .wp-block-latest-posts.columns-3 li{
    width:calc(33.33333% - .83333em);
  }
  .wp-block-latest-posts.columns-3 li:nth-child(3n){
    margin-left:0;
  }
  .wp-block-latest-posts.columns-4 li{
    width:calc(25% - .9375em);
  }
  .wp-block-latest-posts.columns-4 li:nth-child(4n){
    margin-left:0;
  }
  .wp-block-latest-posts.columns-5 li{
    width:calc(20% - 1em);
  }
  .wp-block-latest-posts.columns-5 li:nth-child(5n){
    margin-left:0;
  }
  .wp-block-latest-posts.columns-6 li{
    width:calc(16.66667% - 1.04167em);
  }
  .wp-block-latest-posts.columns-6 li:nth-child(6n){
    margin-left:0;
  }
}

:root :where(.wp-block-latest-posts.is-grid){
  padding:0;
}
:root :where(.wp-block-latest-posts.wp-block-latest-posts__list){
  padding-right:0;
}

.wp-block-latest-posts__post-author,.wp-block-latest-posts__post-date{
  display:block;
  font-size:.8125em;
}

.wp-block-latest-posts__post-excerpt,.wp-block-latest-posts__post-full-content{
  margin-bottom:1em;
  margin-top:.5em;
}

.wp-block-latest-posts__featured-image a{
  display:inline-block;
}
.wp-block-latest-posts__featured-image img{
  height:auto;
  max-width:100%;
  width:auto;
}
.wp-block-latest-posts__featured-image.alignleft{
  float:left;
  margin-right:1em;
}
.wp-block-latest-posts__featured-image.alignright{
  float:right;
  margin-left:1em;
}
.wp-block-latest-posts__featured-image.aligncenter{
  margin-bottom:1em;
  text-align:center;
}